@@ -71,7 +71,8 @@
 #'
 #' @rdname pairwise
 #' @export
-pairwise <- function(fit, correction = "Tukey", term = NULL, alpha = .05, var_equal = TRUE, plot = FALSE) {
+pairwise <- function(fit, correction = "Tukey", term = NULL, alpha = .05, var_equal = TRUE,
+                     plot = FALSE) {
   rlang::arg_match(correction, c("none", "Bonferroni", "Tukey"))
 
   tbl <- switch(correction,
@@ -208,8 +209,8 @@ pairwise_tukey <- function(fit, term = NULL, alpha = .05) {
 #' @param alpha The alpha to use when computing the family-wise error-rate.
 #' @param correction The type of alpha correction the tests in the table use.
 #'
-#' @return A `tibble` sub-classed as `pairwise_comparison_tbl`. These have custom printers and retain
-#'   their attributes when subsetted.
+#' @return A `tibble` sub-classed as `pairwise_comparison_tbl`. These have custom printers and
+#'   retain their attributes when subsetted.
 #' @keywords internal
 new_pairwise_tbl <- function(tbl, term, fit, fwer, alpha, correction) {
   class_name <- "pairwise_tbl"
