@@ -1,22 +1,22 @@
 #' Extract the variables from a model formula
 #'
-#' @param object A \code{\link{formula}}, \code{\link{lm}} or \code{\link{supernova}} object
+#' @param object A [`formula`], [`lm`] or [`supernova`] object
 #'
 #' @importFrom stats formula terms
 #'
-#' @return A list containing the \code{outcome} and \code{predictor} variables in the model.
+#' @return A list containing the `outcome` and `predictor` variables in the model.
 #'
 #' @rdname variables
 #' @export
 variables <- function(object) {
-  UseMethod('variables', object)
+  UseMethod("variables", object)
 }
 
 
 #' @rdname variables
 #' @export
 variables.supernova <- function(object) {
-  variables(object[['fit']])
+  variables(object[["fit"]])
 }
 
 
@@ -39,7 +39,7 @@ variables.formula <- function(object) {
 #' @export
 variables.lm <- function(object) {
   var_list <- variables.formula(formula(object))
-  var_list[['between']] <- var_list[['predictor']]
+  var_list[["between"]] <- var_list[["predictor"]]
   var_list
 }
 
@@ -48,18 +48,18 @@ variables.lm <- function(object) {
 #' @export
 variables.lmerMod <- function(object) {
   frm <- formula(object)
-  var_list <- variables.formula(frm)  # initialize output list
+  var_list <- variables.formula(frm) # initialize output list
 
   # terms = things specified in the model like (1 | group) and mpg:hp
-  # vars = variables that the model uses  like group, mpg, and hp
   fixed_terms <- frm_fixed_terms(frm)
   fixed_vars <- frm_fixed_vars(frm)
-  random_vars <- frm_random_vars(frm)
+  random_terms <- frm_random_terms(frm)
 
   # currently we only support a single grouping variable, logically it must be the random variable
   # with the shortest name --- all other valid random variables will be nested in some way and have
   # (1 | a:b) syntax, where b is the group variable
-  group_var <- random_vars[which.min(nchar(random_vars))]
+  group_var <- random_terms[which.min(nchar(random_terms))] %>%
+    stringr::str_remove("^1 [|] ")
 
   # need to check the data and number of groups to determine within and between below
   data <- object@frame
@@ -80,13 +80,13 @@ variables.lmerMod <- function(object) {
   # any interactive term with a within var is within, otherwise it's between
   interaction_terms <- frm_interaction_terms(frm)
   is_within <- purrr::map_lgl(interaction_terms, function(possible_within) {
-    vars_in_interaction <- stringr::str_split(possible_within, stringr::fixed(':'))[[1]]
+    vars_in_interaction <- stringr::str_split(possible_within, stringr::fixed(":"))[[1]]
     any(vars_in_interaction %in% within_vars)
   })
 
-  var_list[['predictor']] <- fixed_terms
-  var_list[['group']] <- group_var
-  var_list[['within']] <- c(within_vars, interaction_terms[is_within])
-  var_list[['between']] <- c(between_vars, interaction_terms[!is_within])
+  var_list[["predictor"]] <- fixed_terms
+  var_list[["group"]] <- group_var
+  var_list[["within"]] <- c(within_vars, interaction_terms[is_within])
+  var_list[["between"]] <- c(between_vars, interaction_terms[!is_within])
   var_list
 }
