@@ -1,13 +1,10 @@
-context("Value extraction")
 
 test_model <- lm(mpg ~ hp, data = mtcars)
-estimate_funs <- c(b0, b1, fVal, PRE, SSE, SSM, SSR)
+estimate_funs <- c(b0, b1, f, pre, sse, ssm, ssr)
 
 test_that("extracted values are all single element numeric vectors", {
   purrr::map(estimate_funs, function(f) {
-    f(test_model) %>%
-      expect_length(1) %>%
-      expect_is("numeric")
+    expect_vector(f(test_model), double(), 1L)
   })
 })
 
@@ -20,11 +17,11 @@ test_that("values can be extracted from fitted lm or formula-and-data", {
 test_that("extracted values are correct", {
   expect_identical(b0(test_model), test_model$coefficients[[1]])
   expect_identical(b1(test_model), coefficients(test_model)[[2]])
-  expect_identical(fVal(test_model), summary(test_model)$fstatistic[["value"]])
-  expect_identical(PRE(test_model), summary(test_model)$r.squared)
-  expect_identical(SSE(test_model), sum(resid(test_model)^2))
+  expect_identical(f(test_model), summary(test_model)$fstatistic[["value"]])
+  expect_identical(pre(test_model), summary(test_model)$r.squared)
+  expect_identical(sse(test_model), sum(resid(test_model)^2))
 
   ssr_expected <- sum((test_model$fitted.values - mean(test_model$model[[1]]))^2)
-  expect_identical(SSR(test_model), ssr_expected)
-  expect_identical(SSM(test_model), SSR(test_model))
+  expect_identical(ssr(test_model), ssr_expected)
+  expect_identical(ssm(test_model), ssr(test_model))
 })
